[evolution-data-server/gnome-3-20] Bug 766747 - WebDAV discovery for GMX CalDAV server fails ][



commit c5d37e50e48e97ca1cafd574f9bb63c265ca14f3
Author: Milan Crha <mcrha redhat com>
Date:   Tue May 24 18:55:56 2016 +0200

    Bug 766747 - WebDAV discovery for GMX CalDAV server fails ][
    
    Do not report failure, but also do not forget the error, thus when
    anything fails, there is shown some information what failed, instead
    of ending with an empty window.

 libedataserver/e-webdav-discover.c |   18 +++++++++---------
 1 files changed, 9 insertions(+), 9 deletions(-)
---
diff --git a/libedataserver/e-webdav-discover.c b/libedataserver/e-webdav-discover.c
index fcd51bb..8fe1e3a 100644
--- a/libedataserver/e-webdav-discover.c
+++ b/libedataserver/e-webdav-discover.c
@@ -943,8 +943,8 @@ e_webdav_discover_get_calendar_collection_details (SoupSession *session,
 
                if (g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_FAILED) ||
                    g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND)) {
-                       /* Ignore these errors */
-                       g_clear_error (&local_error);
+                       /* Ignore these errors, but still propagate them. */
+                       g_propagate_error (error, local_error);
                        return TRUE;
                } else if (local_error) {
                        g_propagate_error (error, local_error);
@@ -1002,8 +1002,8 @@ e_webdav_discover_process_calendar_home_set (SoupSession *session,
        if (!doc) {
                if (g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_FAILED) ||
                    g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND)) {
-                       /* Ignore these errors */
-                       g_clear_error (&local_error);
+                       /* Ignore these errors, but still propagate them. */
+                       g_propagate_error (error, local_error);
                        return TRUE;
                } else if (local_error) {
                        g_propagate_error (error, local_error);
@@ -1369,8 +1369,8 @@ e_webdav_discover_get_addressbook_collection_details (SoupSession *session,
 
                if (g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_FAILED) ||
                    g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND)) {
-                       /* Ignore these errors */
-                       g_clear_error (&local_error);
+                       /* Ignore these errors, but still propagate them. */
+                       g_propagate_error (error, local_error);
                        return TRUE;
                } else if (local_error) {
                        g_propagate_error (error, local_error);
@@ -1426,8 +1426,8 @@ e_webdav_discover_process_addressbook_home_set (SoupSession *session,
        if (!doc) {
                if (g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_FAILED) ||
                    g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND)) {
-                       /* Ignore these errors */
-                       g_clear_error (&local_error);
+                       /* Ignore these errors, but still propagate them. */
+                       g_propagate_error (error, local_error);
                        return TRUE;
                } else if (local_error) {
                        g_propagate_error (error, local_error);
@@ -2018,7 +2018,7 @@ e_webdav_discover_sources_sync (ESource *source,
                if (success && (only_supports == E_WEBDAV_DISCOVER_SUPPORTS_NONE ||
                    (only_supports & (E_WEBDAV_DISCOVER_SUPPORTS_CONTACTS)) != 0)) {
                        success = e_webdav_discover_process_addressbook_home_set (session, message, source, 
out_certificate_pem,
-                               out_certificate_errors, &addressbooks, cancellable, &local_error);
+                               out_certificate_errors, &addressbooks, cancellable, local_error ? NULL : 
&local_error);
 
                        if (!addressbooks && !g_cancellable_is_cancelled (cancellable) && (!soup_uri_get_path 
(soup_uri) ||
                            !strstr (soup_uri_get_path (soup_uri), "/.well-known/"))) {


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]